@@ -166,13 +166,10 @@ sub _gc_expired () {
   my ($this) = @_; 
 
 
-  my $time = time(); 
-  foreach my $cache_key (keys %{$this->_KeyCache}) {
-    my $cache_time = $this->_RecordCache->{$cache_key}{'time'} || 0;  
-    $this->_expire($cache_key) 
-      if (($time - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
-  }
-  foreach my $cache_key (keys %{$this->_RecordCache}) {
+  my $time = time();  
+
+  # XXX TODO: do we want to sort the keys beforehand, so we can get out of the loop earlier?
+  foreach my $cache_key (keys %{$this->_KeyCache}, keys %{$this->_RecordCache}) {
     my $cache_time = $this->_RecordCache->{$cache_key}{'time'} || 0 ;  
     $this->_expire($cache_key) 
       if (($time - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
@@ -206,8 +203,8 @@ sub _expire (\$) {
 sub _fetch () { 
   my ($this, $cache_key) = @_;
 
-  $this->{'values'}  = 
-    $this->_RecordCache->{$cache_key}{'values'};
+  $this->{'values'}  = $this->_RecordCache->{$cache_key}{'values'};
+  $this->{'fetched'}  = $this->_RecordCache->{$cache_key}{'fetched'};
   return(1); 
 }
 
@@ -238,8 +235,9 @@ sub _store (\$) {
   my ($this) = @_; 
   my $cache_key = $this->_gen_primary_cache_key();
   $this->{'_CacheConfig'}{'cache_key'} = $cache_key;
-  $this->_RecordCache->{$cache_key}{'values'}=$this->{'values'};
-  $this->_RecordCache->{$cache_key}{'time'}=time();
+  $this->_RecordCache->{$cache_key}{'values'} = $this->{'values'};
+  $this->_RecordCache->{$cache_key}{'fetched'} = $this->{'fetched'};
+  $this->_RecordCache->{$cache_key}{'time'} = time();
   
   return(1);
 }
@@ -254,13 +252,21 @@ sub _store (\$) {
 # Desc    : Takes a perl hash and generates a key from it. 
 
 sub _gen_alternate_cache_key {
-  my ($this, %attr) = @_;
-  my $cache_key=$this->Table() . ':';
-  while (my ($key, $value) = each %attr) {
-    $cache_key .= ($key ||'__undef'). '=' . ($value||'__undef') . ',';
-  }
-  chop ($cache_key);
-  return ($cache_key);
+    my ( $this, %attr ) = @_;
+    my $cache_key = $this->Table() . ':';
+    while ( my ( $key, $value ) = each %attr ) {
+        $key ||= '__undef';
+        $value ||= '__undef';
+
+        if ( ref($value) eq "HASH" ) { 
+            $value = $value->{operator}.$value->{value}; 
+        } else {
+            $value = "=".$value;
+        }    
+        $cache_key .= $key.$value.',';
+    }
+    chop($cache_key);
+    return ($cache_key);
 }
 
 
